@@ -19,60 +19,50 @@ from ConfigParser import ConfigParser, NoOptionError
 from options import Options
 import re, time
 from pprint import pprint
-from parsetime import parsetime
+
+from config import MicroblogConfig
 import microblog
+import logging
+log = logging.getLogger(__name__)
+log.setLevel(logging.DEBUG)
 
 def update(**kwargs):
     if not kwargs:
         opt = Options()
         options = opt.parse()
-        conf = ConfigParser()
+        conf = MicroblogConfig(options.config_filename)
         if options.sample_config:
             from pkg_resources import resource_string
             foo_config = resource_string(__name__, '../docs/default.cfg.sample')
             print(foo_config)
             sys.exit(1)
-        try:
-            fd =  open(options.config_filename, 'r')
-        except IOError:
-            print >>sys.stderr, "File %s not found" % configfile
-            sys.exit(2)
-        conf.readfp(fd)
-
-        url = conf.get("global", "url").strip()
-        service = conf.get("global", "service").strip()
-        username = conf.get("global", "username").strip()
-        password = conf.get("global", "password").strip()
-        mode = conf.get("global","mode").strip()
-        try:
-            items = int(conf.get("global","items").strip())
-        except NoOptionError:
-            items = 5
-
-        try:
-            interval = parsetime(conf.get("global","interval").strip())
-        except:
-            print('Error in the interval setting')
-            sys.exit(1)
-
-        try:
-            shortener = conf.get('global','shortener').strip()
-        except NoOptionError:
-            shortener = 'tinyurl'
+        if options.log_filename:
+            fh = logging.FileHandler(options.log_filename)
+            formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
+            fh.setFormatter(formatter)
+            log.addHandler(fh)
+#            microblog.log.addHandler(fh)
+        else:
+            logging.basicConfig(level=logging.DEBUG,
+                    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
+            )
+        configs = conf.configs()
     else:
+        configs=[]
+        kwargs['items'] = 5
+        configs.append(kwargs)
         url = kwargs['url']
-        username = kwargs['username']
-        password = kwargs['password']
-        mode = kwargs['mode']
-        items = 5
         shortener = kwargs['shortener']
-        interval = parsetime('00:05')
-        service = kwargs['service']
+        kwargs['interval'] = parsetime('00:05')
 
+    log.debug('Starting feed2mb')
     while True:
-        the_service = microblog.service[service](url, username, password, mode, items, shortener)
-        the_service.update()
+        interval = configs[0]['interval']
+        for cf in configs:
+            the_service = microblog.service(**cf).get()
+            the_service.update()
+            log.debug('next ' + cf['service'] + ' update in: ' + str(interval) + ' seconds')
         time.sleep(interval)
 
-__version__ = '0.6.7'
+__version__ = '0.7'
 
