@@ -1,3 +1,4 @@
+
 # feed2twitter
 # Copyright (C) 2008 Walter Cruz <walter@waltercruz.com>
 #
@@ -21,12 +22,13 @@ import md5
 
 class parse(object):
 
-    def __init__(self,feed_url):
+    def __init__(self,feed_url,service):
         self.feed_url = feed_url
+        self.service = service
         self.feed = feedparser.parse(feed_url)
 
     def getStampFileName(self):
-        self.md5name = md5.md5(self.feed_url).hexdigest()
+        self.md5name = md5.md5(self.feed_url + self.service).hexdigest()
         self.directory = os.path.expanduser("~/.feed2mb/")
         self.filename = self.directory + self.md5name
 
